<?php
/**
 * Plugin Name: Fedya's dynamic author information
 * Plugin URI: https://fedia.eu/dynamic-author-information
 * Description: Adds customizable author information to posts with admin interface
 * Version: 1.0.1
 * Author: Fedya Serafiev
 * Author URI: https://fedia.eu
 * Text Domain: dynamic-author-information
 * Domain Path: /languages
 * License: GPL v2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */

// Prevent direct access to this file
if (!defined('ABSPATH')) {
    exit;
}

// Create database table on plugin activation
function dai_create_plugin_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'dynamic_author_info';
    
    $charset_collate = $wpdb->get_charset_collate();
    
    $sql = "CREATE TABLE IF NOT EXISTS $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        author_name varchar(100) NOT NULL,
        author_bio text NOT NULL,
        author_image_url varchar(255),
        author_link varchar(255),
        PRIMARY KEY  (id)
    ) $charset_collate;";
    
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}
register_activation_hook(__FILE__, 'dai_create_plugin_table');

// Add admin menu
function dai_add_admin_menu() {
    add_menu_page(
        'Author Information Settings',
        'Author Info',
        'manage_options',
        'dynamic-author-info',
        'dai_admin_page',
        'dashicons-businessman',
        30
    );
}
add_action('admin_menu', 'dai_add_admin_menu');

// Create admin page
function dai_admin_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'dynamic_author_info';
    
    // Handle form submission
    if (isset($_POST['dai_submit'])) {
        $author_name = sanitize_text_field($_POST['author_name']);
        $author_bio = sanitize_textarea_field($_POST['author_bio']);
        $author_link = sanitize_url($_POST['author_link']);
        
        // Handle image upload
        if (!empty($_FILES['author_image']['name'])) {
            require_once(ABSPATH . 'wp-admin/includes/image.php');
            require_once(ABSPATH . 'wp-admin/includes/file.php');
            require_once(ABSPATH . 'wp-admin/includes/media.php');
            
            $attachment_id = media_handle_upload('author_image', 0);
            if (!is_wp_error($attachment_id)) {
                $author_image_url = wp_get_attachment_url($attachment_id);
            }
        } else {
            $author_image_url = $_POST['existing_image_url'];
        }
        
        // Update or insert data
        $existing_data = $wpdb->get_row("SELECT id FROM $table_name LIMIT 1");
        if ($existing_data) {
            $wpdb->update(
                $table_name,
                array(
                    'author_name' => $author_name,
                    'author_bio' => $author_bio,
                    'author_image_url' => $author_image_url,
                    'author_link' => $author_link
                ),
                array('id' => $existing_data->id)
            );
        } else {
            $wpdb->insert(
                $table_name,
                array(
                    'author_name' => $author_name,
                    'author_bio' => $author_bio,
                    'author_image_url' => $author_image_url,
                    'author_link' => $author_link
                )
            );
        }
        echo '<div class="notice notice-success"><p>Settings saved successfully!</p></div>';
    }
    
    // Get existing data
    $author_info = $wpdb->get_row("SELECT * FROM $table_name LIMIT 1");
    ?>
    <div class="wrap">
        <h1>Author Information Settings</h1>
        <form method="post" enctype="multipart/form-data" class="dai-admin-form">
            <table class="form-table">
                <tr>
                    <th><label for="author_name">Author Name</label></th>
                    <td>
                        <input type="text" name="author_name" id="author_name" class="regular-text" 
                               value="<?php echo esc_attr($author_info->author_name ?? ''); ?>" required>
                    </td>
                </tr>
                <tr>
                    <th><label for="author_bio">Author Bio</label></th>
                    <td>
                        <textarea name="author_bio" id="author_bio" rows="5" class="large-text" required><?php 
                            echo esc_textarea($author_info->author_bio ?? ''); 
                        ?></textarea>
                    </td>
                </tr>
                <tr>
                    <th><label for="author_link">Author Website</label></th>
                    <td>
                        <input type="url" name="author_link" id="author_link" class="regular-text" 
                               value="<?php echo esc_url($author_info->author_link ?? ''); ?>">
                    </td>
                </tr>
                <tr>
                    <th><label for="author_image">Author Image</label></th>
                    <td>
                        <?php if (!empty($author_info->author_image_url)): ?>
                            <img src="<?php echo esc_url($author_info->author_image_url); ?>" 
                                 style="max-width: 100px; margin-bottom: 10px;"><br>
                        <?php endif; ?>
                        <input type="hidden" name="existing_image_url" 
                               value="<?php echo esc_url($author_info->author_image_url ?? ''); ?>">
                        <input type="file" name="author_image" id="author_image" accept="image/*">
                        <p class="description">Recommended size: 200x200 pixels</p>
                    </td>
                </tr>
            </table>
            <?php submit_button('Save Settings', 'primary', 'dai_submit'); ?>
        </form>
    </div>
    <?php
}

// Add author info to content
function dai_add_dynamic_author_info($content) {
    if (is_single()) {
        global $wpdb;
        $table_name = $wpdb->prefix . 'dynamic_author_info';
        $author_info = $wpdb->get_row("SELECT * FROM $table_name LIMIT 1");
        
        if ($author_info) {
            $author_box = '<div class="dynamic-author-info-box">';
            if (!empty($author_info->author_image_url)) {
                $author_box .= '<div class="dynamic-author-avatar">';
                $author_box .= '<img src="' . esc_url($author_info->author_image_url) . '" alt="' . 
                              esc_attr($author_info->author_name) . '">';
                $author_box .= '</div>';
            }
            $author_box .= '<div class="dynamic-author-details">';
            if (!empty($author_info->author_link)) {
                $author_box .= '<h4><a href="' . esc_url($author_info->author_link) . '" class="dynamic-author-link">' . 
                              esc_html($author_info->author_name) . '</a></h4>';
            } else {
                $author_box .= '<h4>' . esc_html($author_info->author_name) . '</h4>';
            }
            $author_box .= '<p>' . esc_html($author_info->author_bio) . '</p>';
            $author_box .= '</div></div>';
            
            $content .= $author_box;
        }
    }
    return $content;
}
add_filter('the_content', 'dai_add_dynamic_author_info');

// Add styles
function dai_add_styles() {
    ?>
    <style>
    .dynamic-author-info-box {
        background: linear-gradient(to right, #ffffff, #f8f9fa);
        border-radius: 12px;
        box-shadow: 0 4px 6px rgba(0, 0, 0, 0.05);
        margin: 2rem 0;
        padding: 2rem;
        display: flex;
        align-items: flex-start;
        gap: 2rem;
        transition: all 0.3s ease;
    }

    .dynamic-author-info-box:hover {
        box-shadow: 0 6px 12px rgba(0, 0, 0, 0.1);
        transform: translateY(-2px);
    }

    .dynamic-author-avatar {
        flex-shrink: 0;
    }

    .dynamic-author-avatar img {
        width: 120px;
        height: 120px;
        border-radius: 50%;
        object-fit: cover;
        border: 4px solid #fff;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .dynamic-author-details {
        flex-grow: 1;
    }

    .dynamic-author-details h4 {
        color: #2c3e50;
        font-size: 1.5rem;
        margin: 0 0 1rem;
        font-weight: 600;
    }

    .dynamic-author-link {
        color: #3498db !important;
        text-decoration: none !important;
        transition: color 0.2s ease;
    }

    .dynamic-author-link:hover {
        color: #2980b9 !important;
    }

    .dynamic-author-details p {
        color: #5a6c7d;
        font-size: 1rem;
        line-height: 1.6;
        margin: 0;
    }

    /* Admin styles */
    .dai-admin-form .form-table td {
        padding: 20px 10px;
    }

    .dai-admin-form input[type="text"],
    .dai-admin-form input[type="url"],
    .dai-admin-form textarea {
        width: 100%;
        max-width: 500px;
        padding: 8px;
        border: 1px solid #ddd;
        border-radius: 4px;
    }

    .dai-admin-form .button-primary {
        background: #3498db;
        border-color: #2980b9;
    }

    @media (max-width: 768px) {
        .dynamic-author-info-box {
            flex-direction: column;
            align-items: center;
            text-align: center;
            padding: 1.5rem;
        }

        .dynamic-author-avatar {
            margin-bottom: 1rem;
        }
    }
    </style>
    <?php
}
add_action('wp_head', 'dai_add_styles');
add_action('admin_head', 'dai_add_styles');
